Specter-desktop is an Open Source Project under the MIT-License and everyone is invited to contribute to it.

We haven't created many explicit processes and rely on the best practices of Open Source projects. If you want to contribute, fork the project and create a PR. 

If it's necessary to add processes, we'll probably looking into Pieter Hintjens' [Social Architecture](https://hintjens.gitbooks.io/social-architecture/content/) and specifically the C4 process. Pieter is explicitly mentioning two roles: Contributors and maintainers. 

Thank you very much to all our [Contributors](https://github.com/cryptoadvance/specter-desktop/graphs/contributors). 
See also the Contributors to each specific release in the release-notes.

The maintainers are the ones who are able to merge PRs and create tags/releases. They are listed as "authors" in setup.py.

For practical considerations of a dev-setup, please have a look in the [development.md](development.md). If you need support, join our  [Telegram group](https://t.me/spectersupport). 
